==> lambdasns-2.17.0-sources.jar: software/amazon/awsconstructs/services/lambdasns/LambdaToSns.java <==
package software.amazon.awsconstructs.services.lambdasns;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.64.0 (build 4c1eae8)", date = "2022-08-17T14:31:03.256Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdasns.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-sns.LambdaToSns")
public class LambdaToSns extends software.constructs.Construct {

    protected LambdaToSns(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToSns(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToSns(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return software.amazon.jsii.Kernel.get(this, "snsTopic", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.Topic.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdasns.LambdaToSns> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingTopicObj Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. This parameter is required.
         */
        public Builder existingTopicObj(final software.amazon.awscdk.services.sns.Topic existingTopicObj) {
            this.props.existingTopicObj(existingTopicObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the arn of the Topic.
         * <p>
         * Default: - SNS_TOPIC_ARN
         * <p>
         * @return {@code this}
         * @param topicArnEnvironmentVariableName Optional Name for the Lambda function environment variable set to the arn of the Topic. This parameter is required.
         */
        public Builder topicArnEnvironmentVariableName(final java.lang.String topicArnEnvironmentVariableName) {
            this.props.topicArnEnvironmentVariableName(topicArnEnvironmentVariableName);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the Topic.
         * <p>
         * Default: - SNS_TOPIC_NAME
         * <p>
         * @return {@code this}
         * @param topicNameEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the Topic. This parameter is required.
         */
        public Builder topicNameEnvironmentVariableName(final java.lang.String topicNameEnvironmentVariableName) {
            this.props.topicNameEnvironmentVariableName(topicNameEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final software.amazon.awscdk.services.sns.TopicProps topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdasns.LambdaToSns build() {
            return new software.amazon.awsconstructs.services.lambdasns.LambdaToSns(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdasns-2.43.1-sources.jar: software/amazon/awsconstructs/services/lambdasns/LambdaToSns.java <==
package software.amazon.awsconstructs.services.lambdasns;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-08-29T00:17:20.181Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdasns.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-sns.LambdaToSns")
public class LambdaToSns extends software.constructs.Construct {

    protected LambdaToSns(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToSns(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public LambdaToSns(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return software.amazon.jsii.Kernel.get(this, "snsTopic", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.Topic.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdasns.LambdaToSns> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key.
         * <p>
         * This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.
         * <p>
         * Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
         * <p>
         * @return {@code this}
         * @param enableEncryptionWithCustomerManagedKey If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This parameter is required.
         */
        public Builder enableEncryptionWithCustomerManagedKey(final java.lang.Boolean enableEncryptionWithCustomerManagedKey) {
            this.props.enableEncryptionWithCustomerManagedKey(enableEncryptionWithCustomerManagedKey);
            return this;
        }

        /**
         * An optional, imported encryption key to encrypt the SNS Topic with.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param encryptionKey An optional, imported encryption key to encrypt the SNS Topic with. This parameter is required.
         */
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.Key encryptionKey) {
            this.props.encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param encryptionKeyProps Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. This parameter is required.
         */
        public Builder encryptionKeyProps(final software.amazon.awscdk.services.kms.KeyProps encryptionKeyProps) {
            this.props.encryptionKeyProps(encryptionKeyProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingTopicObj Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. This parameter is required.
         */
        public Builder existingTopicObj(final software.amazon.awscdk.services.sns.Topic existingTopicObj) {
            this.props.existingTopicObj(existingTopicObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the arn of the Topic.
         * <p>
         * Default: - SNS_TOPIC_ARN
         * <p>
         * @return {@code this}
         * @param topicArnEnvironmentVariableName Optional Name for the Lambda function environment variable set to the arn of the Topic. This parameter is required.
         */
        public Builder topicArnEnvironmentVariableName(final java.lang.String topicArnEnvironmentVariableName) {
            this.props.topicArnEnvironmentVariableName(topicArnEnvironmentVariableName);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the Topic.
         * <p>
         * Default: - SNS_TOPIC_NAME
         * <p>
         * @return {@code this}
         * @param topicNameEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the Topic. This parameter is required.
         */
        public Builder topicNameEnvironmentVariableName(final java.lang.String topicNameEnvironmentVariableName) {
            this.props.topicNameEnvironmentVariableName(topicNameEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final software.amazon.awscdk.services.sns.TopicProps topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdasns.LambdaToSns build() {
            return new software.amazon.awsconstructs.services.lambdasns.LambdaToSns(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
